Attribute VB_Name = "PCIELM4"
'//-----------------------------------------------------------------------------------------
'//File Name:PCIELM4.bas
'//Update date:2020/01/06 by Dan Huang
'//Support Language: Visual Basic 6.0
'//-----------------------------------------------------------------------------------------

Option Explicit

Global Const MAX_BOARD_NUMBER = 32
Global Const MAX_EVENT_NUMBER = 20
Global Const MAX_AO_CHANNEL = 32

'//Option Mode
Global Const MULTIPROCESSOR = 1
Global Const ENABLEMEMIO = 2
Global Const ENABLEDMAAI = 16

'ModelNumber
Global Const PCIELM4 = &HD61E39

Global Const MAX_CFGCODE_NUMBER = 4

'User Analog Input Config Code

Global Const PCIELM4_AI_BI_10V = 0      'Bipolar +/- 10V
Global Const PCIELM4_AI_BI_5V = 1       'Bipolar +/-  5V
Global Const PCIELM4_AI_BI_2V5 = 2      'Bipolar +/-  2.5V
Global Const PCIELM4_AI_BI_1V25 = 3     'Bipolar +/-  1.25V
Global Const PCIELM4_AI_BI_227MV = 0       'Bipolar +/-  227 mV

'AI Sampling Rate
Global Const PCIELM4_AIRATE_15000 = 15000
Global Const PCIELM4_AIRATE_7500 = 7500
Global Const PCIELM4_AIRATE_3750 = 3750
Global Const PCIELM4_AIRATE_1000 = 1000
Global Const PCIELM4_AIRATE_500 = 500
Global Const PCIELM4_AIRATE_30 = 30
Global Const PCIELM4_AIRATE_15 = 15


'//User Analog Output Config Code for Voltage
Global Const PCIELM4_AO_UNI_5V = 0       'Unipolar 0  ~  5 V
Global Const PCIELM4_AO_UNI_10V = 1      'Unipolar 0  ~ 10 V
Global Const PCIELM4_AO_BI_5V = 2        'Bipolar  +/-   5 V
Global Const PCIELM4_AO_BI_10V = 3       'Bipolar +/-  10 V
Global Const PCIELM4_AO_BI_227MV = 0       'Bipolar +/-  227 mV



'// Return code
Global Const PCIELM4_NoErr = 0  '//Correct
Global Const PCIELM4_OpenDriverErr = 1  '//Open driver error
Global Const PCIELM4_PnPDriverErr = 2  '//Plug & Play error
Global Const PCIELM4_DriverNoOpen = 3  '//The driver was not open
Global Const PCIELM4_GetDriverVersionErr = 4  '//Recieve driver version error
Global Const PCIELM4_ExceedBoardNumber = 5  '//Board number error
Global Const PCIELM4_FindBoardErr = 6  '//No board found
Global Const PCIELM4_BoardMappingErr = 7  '//Board Mapping error
Global Const PCIELM4_DIOModesErr = 8  '//Digital input/output mode setting error
Global Const PCIELM4_InvalidAddress = 9  '//Invalid address
Global Const PCIELM4_InvalidSize = 10  '//Invalid size
Global Const PCIELM4_InvalidPortNumber = 11  '//Invalid port number
Global Const PCIELM4_UnSupportedModel = 12  '//This board model is not supported
Global Const PCIELM4_UnSupportedFun = 13  '//This function is not supported
Global Const PCIELM4_InvalidChannelNumber = 14  '//Invalid channel number
Global Const PCIELM4_InvalidValue = 15  '//Invalid value
Global Const PCIELM4_InvalidMode = 16  '//Invalid mode
Global Const PCIELM4_GetAIStatusTimeOut = 17  '//A timeout occurred while receiving the status of the analog input
Global Const PCIELM4_TimeOutErr = 18  '//Timeout error
Global Const PCIELM4_CfgCodeIndexErr = 19  '//A compatible configuration code table index could not be found
Global Const PCIELM4_ADCCTLTimeoutErr = 20  '//ADC controller a timeout error
Global Const PCIELM4_FindPCIIndexErr = 21  '//A compatible PCI table index value could not be found
Global Const PCIELM4_InvalidSetting = 22  '//Invalid setting value
Global Const PCIELM4_AllocateMemErr = 23  '//Error while allocating the memory space
Global Const PCIELM4_InstallEventErr = 24  '//Error while installing the interrupt event
Global Const PCIELM4_InstallIrqErr = 25  '//Error while installing the interrupt IRQ
Global Const PCIELM4_RemoveIrqErr = 26  '//Error while removing the interrupt IRQ
Global Const PCIELM4_ClearIntCountErr = 27  '//Error while the clear interrupt count
Global Const PCIELM4_GetSysBufferErr = 28  '//Error while retrieving the system buffer
Global Const PCIELM4_CreateEventErr = 29  '//Error while create the event
Global Const PCIELM4_UnSupportedResolution = 30  '//Resolution not supported
Global Const PCIELM4_CreateThreadErr = 31  '//Error while create the thread
Global Const PCIELM4_ThreadTimeOutErr = 32  '//Thread timeout error
Global Const PCIELM4_FIFOOverFlowErr = 33  '//FIFO overflow error
Global Const PCIELM4_FIFOTimeOutErr = 34  '//FIFO timeout error
Global Const PCIELM4_GetIntInstStatus = 35  '//Retrieves the status of the interrupt installation
Global Const PCIELM4_GetBufStatus = 36  '//Retrieves the status of the system buffer
Global Const PCIELM4_SetBufCountErr = 37  '//Error while setting the buffer count
Global Const PCIELM4_SetBufInfoErr = 38  '//Error while setting the buffer data
Global Const PCIELM4_FindCardIDErr = 39  '//Card ID code could not be found
Global Const PCIELM4_EventThreadErr = 40  '//Event Thread error
Global Const PCIELM4_AutoCreateEventErr = 41  '//Error while automatically creating an event
Global Const PCIELM4_RegThreadErr = 42  '//Register Thread error
Global Const PCIELM4_SearchEventErr = 43  '//Search Event error
Global Const PCIELM4_FifoResetErr = 44  '//Error while resetting the FIFO
Global Const PCIELM4_InvalidBlock = 45  '//Invalid EEPROM block
Global Const PCIELM4_InvalidAddr = 46  '//Invalid EEPROM address
Global Const PCIELM4_AcqireSpinLock = 47  '//Error while acquiring spin lock
Global Const PCIELM4_ReleaseSpinLock = 48  '//Error while releasing spin lock
Global Const PCIELM4_SetControlErr = 49  '//Analog input setting error
Global Const PCIELM4_InvalidChannels = 50  '//Invalid channel number
Global Const PCIELM4_SearchCardErr = 51  '//Invalid model number
Global Const PCIELM4_SetMapAddressErr = 52  '//Error while setting the mapping address
Global Const PCIELM4_ReleaseMapAddressErr = 53  '//Error while releasing the mapping address
Global Const PCIELM4_InvalidOffset = 54  '//Invalid memory offset
Global Const PCIELM4_ShareHandleErr = 55  '//Open the share memory fail
Global Const PCIELM4_InvalidDataCount = 56  '//Invalid data count
Global Const PCIELM4_WriteEEPErr = 57  '//Error while writing the EEPROM
Global Const PCIELM4_CardIOErr = 58  '//CardIO error
Global Const PCIELM4_IOErr = 59  '//MemoryIO error
Global Const PCIELM4_SetScanChannelErr = 60
Global Const PCIELM4_SetScanConfigErr = 61
Global Const PCIELM4_GetMMIOMapStatus = 62

Public Type PCIELM4_DEVICE_INFO
    AdwSize As Long
    
    wVendorID As Integer
    wDeviceID As Integer
    
    wSubVendorID As Integer
    wSubDeviceID As Integer
    dwBar(0 To 5)  As Long
   
    BusNo As Byte
    DevNo As Byte
    IRQ As Byte
    Aux As Byte
        
    dwBarVirtualAddress(0 To 5) As Long
End Type

Public Type PCIELM4_CARD_INFO
    dwSize As Long        'Structure size
    dwModelNo As Long         'Model Number
    
   'CardID is update when calling the function each time.
    CardID As Byte            'for new cards, =&hFF=N/A
    wSingleEnded As Byte   'for new cards,1:S.E 2:D.I.F,=&hFF=N/A
    wReserved As Integer      'Reserver

    wAIChannels As Integer    'Number of AI channels(AD)
    wAOChannels As Integer        'Number of AO channels(DA)

    wDIPorts As Integer           'Number of DI ports
    wDOPorts As Integer           'Number of DO ports

    wDIOPorts As Integer          'Number of DIO ports
    wDIOPortWidth As Integer      'The width is 8/16/32 bit.

    wCounterChannels As Integer   'Number of Timers/Counters
    wMemorySize As Integer        'PCI-M512==>512, Units in KB.

    dwReserved1(0 To 5) As Long  'Reserver
End Type


'Driver functions
Declare Function PCIELM4_DriverInit Lib "PCIELM4.DLL" (ByRef wTotalBoard As Integer) As Integer
Declare Function PCIELM4_DriverClose Lib "PCIELM4.DLL" () As Integer
Declare Function PCIELM4_GetCardInfo Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByRef sDevInfo As PCIELM4_DEVICE_INFO, ByRef sCardInfo As PCIELM4_CARD_INFO, ByVal szModelNmae As String) As Integer


'Digital I/O function
Declare Function PCIELM4_WriteDO Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal dwDOVal As Long) As Integer
Declare Function PCIELM4_ReadDI Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByRef dwDIVal As Long) As Integer

'Analog Output
Declare Function PCIELM4_ConfigAO Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wMode As Integer, ByVal wCfgCode As Integer) As Integer
Declare Function PCIELM4_WriteAOVoltage Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal fValue As Single) As Integer
Declare Function PCIELM4_WriteAOVoltageH Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal hValue As Long) As Integer
Declare Function PCIELM4_StartAOVoltageALL Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal fSamplingRate As Single, ByVal dwDataCount As Long, ByVal dwCyclyNum As Long, ByRef fValueCH0 As Single, ByRef fValueCH1 As Single) As Integer
Declare Function PCIELM4_StartAOVoltageALLH Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal fSamplingRate As Single, ByVal dwDataCount As Long, ByVal dwCyclyNum As Long, ByRef dwValueCH0 As Long, ByRef dwValueCH1 As Long) As Integer
Declare Function PCIELM4_StopAOALL Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer) As Integer

'Analog Input
Declare Function PCIELM4_ConfigAIAutoZero Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wEnableAutoZero As Integer) As Integer
Declare Function PCIELM4_SaveAIAutoZeroVal Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal lSamplingRate As Long, ByVal dwAutoZeroValue As Long) As Integer
Declare Function PCIELM4_ConfigAI Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wFIFOSizeKB As Integer, ByVal BufferSizeKB As Long, ByVal wCardType As Integer, ByVal wDelaySettlingTime As Integer, ByVal dwMode As Long) As Integer
Declare Function PCIELM4_PollingAI Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal lSamplingRate As Long, ByVal dwDataCount As Long, ByRef fValue As Double) As Integer
Declare Function PCIELM4_PollingAIH Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal lSamplingRate As Long, ByVal dwDataCount As Long, ByRef dwValue As Long) As Integer

Declare Function PCIELM4_AIHex2Vol Lib "PCIELM4.DLL" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal dwVal As Long, ByRef dVal As Double) As Integer



